zftools: Find the zero forcing set of graphs
============================================

Description
-----------

Find the zero forcing set of graphs

License
-------

GPLv3

Upstream Contact
----------------

- https://pypi.org/project/zftools/
- https://github.com/passagemath/passagemath-pkg-zftools
